@@ -25,16 +25,6 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
     params_general = params$params_general
     params_cleaning = params$params_cleaning
   }
-  #get input variables
-  if (length(input) > 0) {
-    for (i in 1:length(names(input))) {
-      txt = paste0(names(input)[i], "=", input[i])
-      if (is(unlist(input[i]), "character")) {
-        txt = paste0(names(input)[i], "='", unlist(input[i]), "'")
-      }
-      eval(parse(text = txt))
-    }
-  }
   
   metrics2do = data.frame(do.bfen = params_metrics[["do.bfen"]],
                           do.enmo = params_metrics[["do.enmo"]],
@@ -68,11 +58,8 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
                           do.zcz = params_metrics[["do.zcz"]],
                           do.brondcounts = params_metrics[["do.brondcounts"]],
                           do.neishabouricounts = params_metrics[["do.neishabouricounts"]],
-                          stringsAsFactors = TRUE)
-  if (length(params_rawdata[["chunksize"]]) == 0) params_rawdata[["chunksize"]] = 1
-  if (params_rawdata[["chunksize"]] > 1.5) params_rawdata[["chunksize"]] = 1.5
-  if (params_rawdata[["chunksize"]] < 0.2) params_rawdata[["chunksize"]] = 0.2
-  gyro_available = FALSE
+                          stringsAsFactors = FALSE)
+  
   nmetrics = sum(c(params_metrics[["do.bfen"]], params_metrics[["do.enmo"]],
                    params_metrics[["do.lfenmo"]], params_metrics[["do.en"]],
                    params_metrics[["do.hfen"]], params_metrics[["do.hfenplus"]],
@@ -94,44 +81,30 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   if (length(myfun) != 0) {
     nmetrics = nmetrics + length(myfun$colnames)
     # check myfun object already, because we do not want to discover
-    # bugs after waiting for the data to be load
+    # bugs after waiting for the data to load
     check_myfun(myfun, params_general[["windowsizes"]])
   }
   
   if (length(nmetrics) == 0) {
-    if (verbose == TRUE) cat("\nWARNING: No metrics selected\n")
+    warning("No metrics selected.", call. = FALSE)
   }
-  filename = unlist(strsplit(as.character(datafile),"/"))
-  filename = filename[length(filename)]
-  # parameters
-  ws3 = params_general[["windowsizes"]][1]; ws2 = params_general[["windowsizes"]][2]; ws = params_general[["windowsizes"]][3]  #window sizes
-  if ((ws2/60) != round(ws2/60)) {
-    ws2 = as.numeric(60 * ceiling(ws2/60))
-    if (verbose == TRUE) {
-      cat("\nWARNING: The long windowsize needs to be a multitude of 1 minute periods. The\n")
-      cat(paste0("\nlong windowsize has now been automatically adjusted to: ", ws2, " seconds in order to meet this criteria.\n"))
-    }
-  }
-  if ((ws2/ws3) != round(ws2/ws3)) {
-    def = c(1,5,10,15,20,30,60)
-    def2 = abs(def - ws3)
-    ws3 = as.numeric(def[which(def2 == min(def2))])
-    if (verbose == TRUE) {
-      cat("\nWARNING: The long windowsize needs to be a multitude of short windowsize. The \n")
-      cat(paste0("\nshort windowsize has now been automatically adjusted to: ", ws3, " seconds in order to meet this criteria.\n"))
-    }
-  }
-  params_general[["windowsizes"]] = c(ws3,ws2,ws)
-  data = PreviousEndPage = PreviousStartPage = starttime = wday = wdayname = c()
+
+  ws3 = params_general[["windowsizes"]][1]; ws2 = params_general[["windowsizes"]][2]; ws = params_general[["windowsizes"]][3]
+
+  PreviousEndPage = c()
   
   filequality = data.frame(filetooshort = FALSE, filecorrupt = FALSE,
-                           filedoesnotholdday = FALSE, NFilePagesSkipped = 0, stringsAsFactors = TRUE)
+                           filedoesnotholdday = FALSE, NFilePagesSkipped = 0)
+  filetooshort = FALSE
+  filecorrupt = FALSE
+  filedoesnotholdday = FALSE
+  NFilePagesSkipped = 0
+  
   i = 1 #counter to keep track of which binary block is being read
   count = 1 #counter to keep track of the number of seconds that have been read
   count2 = 1 #count number of blocks read with length "ws2" (long epoch, 15 minutes by default)
   LD = 2 #dummy variable used to identify end of file and to make the process stop
   bsc_qc = data.frame(time = c(), size = c(), stringsAsFactors = FALSE)
-  # inspect file
   
   if (length(inspectfileobject) > 0) {
     INFI = inspectfileobject
@@ -142,81 +115,45 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
   mon = INFI$monc
   dformat = INFI$dformc
   sf = INFI$sf
-  if (is.null(sf)) {
-    filequality$filecorrupt = TRUE
-    filecorrupt = TRUE
-    filetooshort = FALSE
-    filedoesnotholdday = FALSE
-    NFilePagesSkipped = 0
-    QClog = NULL
-    LD = 0 # to prevent while loop and skip reading of file
-    deviceSerialNumber = "notExtracted"
-  }
-  if (LD > 1) {
-    hvars = g.extractheadervars(INFI)
-    deviceSerialNumber = hvars$deviceSerialNumber
-  }
-  # if GENEActiv csv, deprecated function
-  if (mon == MONITOR$GENEACTIV && dformat == FORMAT$CSV & length(params_rawdata[["rmc.firstrow.acc"]]) == 0) {
-    stop("The GENEActiv csv reading functionality is deprecated in GGIR from the version 2.6-4 onwards. Please, use either the GENEActiv bin files or try to read the csv files with GGIR::read.myacc.csv")
-  }
-  if (mon == MONITOR$ACTIGRAPH) {
-    # If Actigraph then try to specify dynamic range based on Actigraph model
-    if (length(grep(pattern = "CLE", x = deviceSerialNumber)) == 1) {
-      params_rawdata[["dynrange"]] = 6
-    } else if (length(grep(pattern = "MOS", x = deviceSerialNumber)) == 1) {
-      params_rawdata[["dynrange"]] = 8
-    } else if (length(grep(pattern = "NEO", x = deviceSerialNumber)) == 1) {
-      params_rawdata[["dynrange"]] = 6
-    }
-  }
-  if (LD > 1) {
-    if (sf == 0) stop("Sample frequency not recognised") #assume 80Hertz in the absense of any other info
-    header = INFI$header
-    ID = hvars$ID
-    
-    # get now-wear, clip, and blocksize parameters (thresholds)
-    ncb_params = get_nw_clip_block_params(chunksize = params_rawdata[["chunksize"]],
-                                          dynrange = params_rawdata[["dynrange"]],
-                                          mon, rmc.noise = params_rawdata[["rmc.noise"]],
-                                          sf, dformat,
-                                          rmc.dynamic_range = params_rawdata[["rmc.dynamic_range"]])
-    clipthres = ncb_params$clipthres
-    blocksize = ncb_params$blocksize
-    sdcriter = ncb_params$sdcriter
-    racriter = ncb_params$racriter
-    n_decimal_places = 4 # number of decimal places to which features should be rounded
-    #creating matrixes for storing output
-    S = matrix(0,0,4) #dummy variable needed to cope with head-tailing succeeding blocks of data
-    nev = 80*10^7 # number expected values
-    # NR = ceiling((90*10^6) / (sf*ws3)) + 1000 #NR = number of 'ws3' second rows (this is for 10 days at 80 Hz)
-    NR = ceiling(nev / (sf*ws3)) + 1000 #NR = number of 'ws3' second rows (this is for 10 days at 80 Hz)
-    metashort = matrix(" ",NR,(1 + nmetrics)) #generating output matrix for acceleration signal
-    if (mon == MONITOR$ACTIGRAPH || mon == MONITOR$VERISENSE || (mon == MONITOR$AXIVITY && dformat == FORMAT$CSV) ||
-        (mon == MONITOR$AD_HOC && length(params_rawdata[["rmc.col.temp"]]) == 0)) {
-      temp.available = FALSE
-    } else if (mon == MONITOR$GENEACTIV || (mon == MONITOR$AXIVITY && dformat == FORMAT$CWA) ||
-               mon == MONITOR$MOVISENS || (mon == MONITOR$AD_HOC && length(params_rawdata[["rmc.col.temp"]]) > 0)) {
-      temp.available = TRUE
-    }
-    QClog = NULL
-    if (temp.available == FALSE) {
-      metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 4) #generating output matrix for 15 minutes summaries
-    } else if (temp.available == TRUE && mon != MONITOR$MOVISENS && mon != MONITOR$AD_HOC) {
-      metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 7) #generating output matrix for 15 minutes summaries
-    } else if (temp.available == TRUE && (mon == MONITOR$MOVISENS || mon == MONITOR$AD_HOC)) {
-      metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 5) #generating output matrix for 15 minutes summaries
-    }
-    #===============================================
-    # Read file
-    switchoffLD = 0 #dummy variable part "end of loop mechanism"
-    sforiginal = sf
-  } else {
-    metalong = NULL
-    metashort = NULL
+
+  if (is.null(sf)) { # sf is NULL for corrupt files
+    return(invisible(list(filecorrupt = TRUE, filetooshort = FALSE, NFilePagesSkipped = 0,
+                     metalong = c(), metashort = c(), wday = c(), wdayname = c(),
+                     windowsizes = c(), bsc_qc = bsc_qc, QClog = NULL)))
   }
+
+  hvars = g.extractheadervars(INFI)
+  deviceSerialNumber = hvars$deviceSerialNumber
+
+  # get now-wear, clip, and blocksize parameters (thresholds)
+  ncb_params = get_nw_clip_block_params(chunksize = params_rawdata[["chunksize"]],
+                                        dynrange = params_rawdata[["dynrange"]],
+                                        monc = mon, dformat = dformat,
+                                        deviceSerialNumber = deviceSerialNumber,
+                                        rmc.noise = params_rawdata[["rmc.noise"]],
+                                        sf = sf,
+                                        rmc.dynamic_range = params_rawdata[["rmc.dynamic_range"]])
+  clipthres = ncb_params$clipthres
+  blocksize = ncb_params$blocksize
+  sdcriter = ncb_params$sdcriter
+  racriter = ncb_params$racriter
+  n_decimal_places = 4 # number of decimal places to which features should be rounded
+  # creating matrices for storing output
+  S = matrix(0,0,4) #dummy variable needed to cope with head-tailing succeeding blocks of data
+  nev = 80*10^7 # number expected values
+  NR = ceiling(nev / (sf*ws3)) + 1000 #NR = number of 'ws3' second rows (this is for 10 days at 80 Hz)
+  metashort = matrix(" ",NR,(1 + nmetrics)) #generating output matrix for acceleration signal
+  QClog = NULL
+
+  #===============================================
+  # Read file
+  isLastBlock = FALSE # dummy variable part "end of loop mechanism"
+
+  PreviousLastValue = c(0, 0, 1)
+  PreviousLastTime = NULL
+  header = NULL
+
   while (LD > 1) {
-    P = c()
     if (verbose == TRUE) {
       if (i  == 1) {
         cat(paste0("\nLoading chunk: ", i))
@@ -225,121 +162,92 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
       }
     }
     
-    options(warn = -1) #turn off warnings (code complains about unequal rowlengths
-    
-    if (!exists("PreviousLastValue")) PreviousLastValue = c(0, 0, 1)
-    if (!exists("PreviousLastTime")) PreviousLastTime = NULL
     accread = g.readaccfile(filename = datafile, blocksize = blocksize, blocknumber = i,
                             filequality = filequality,
                             ws = ws, PreviousEndPage = PreviousEndPage,
                             inspectfileobject = INFI,
                             PreviousLastValue = PreviousLastValue,
                             PreviousLastTime = PreviousLastTime,
-                            params_rawdata = params_rawdata, params_general = params_general)
+                            params_rawdata = params_rawdata, params_general = params_general, 
+                            header = header)
+    header = accread$header
+
     if ("PreviousLastValue" %in% names(accread$P)) { # output when reading ad-hoc csv
-      P = accread$P[1:2]
       PreviousLastValue = accread$P$PreviousLastValue
       PreviousLastTime = accread$P$PreviousLastTime
-    } else {
-      P = accread$P
-    }
+    } 
+        
     filequality = accread$filequality
     filetooshort = filequality$filetooshort
     filecorrupt = filequality$filecorrupt
     filedoesnotholdday = filequality$filedoesnotholdday
     NFilePagesSkipped = filequality$NFilePagesSkipped
-    switchoffLD = accread$switchoffLD
+    isLastBlock = accread$isLastBlock
     PreviousEndPage = accread$endpage
-    startpage = accread$startpage
-    options(warn = -1) # to ignore warnings relating to failed mmap.load attempt
-    rm(accread); gc()
-    options(warn = 0) # to ignore warnings relating to failed mmap.load attempt
-    if (mon == MONITOR$MOVISENS) { # if movisens, then read temperature
-      PreviousStartPage = startpage
-      temperature = g.readtemp_movisens(datafile, desiredtz = params_general[["desiredtz"]], PreviousStartPage,
-                                        PreviousEndPage, interpolationType = params_rawdata[["interpolationType"]])
-      P = cbind(P, temperature[1:nrow(P)])
-      colnames(P)[4] = "temp"
-    }
-    options(warn = 0) #turn on warnings
+    
     #============
     #process data as read from binary file
-    if (length(P) > 0) { #would have been set to zero if file was corrupt or empty
-      
-      if (mon == MONITOR$GENEACTIV  && dformat == FORMAT$BIN) {
-        data = P$data.out
-      } else if (dformat == FORMAT$CSV) { #csv (Actigraph or ad-hoc csv format)
-        if (params_rawdata[["imputeTimegaps"]] == TRUE) {
-          P = as.data.frame(P)
-          if (ncol(P) == 3) {
-            timeCol = c()
-            xyzCol = names(P)[1:3]
-          } else if (ncol(P) == 4) {
-            timeCol = names(P)[1]
-            xyzCol = names(P)[2:4]
+    if (length(accread$P) > 0) { # would have been set to zero if file was corrupt or empty
+      data = accread$P$data
+      QClog = rbind(QClog, accread$P$QClog)
+      rm(accread)
+
+      if (i == 1) {
+        light.available = ("light" %in% colnames(data))
+
+        use.temp = ("temperature" %in% colnames(data))
+        if (use.temp) {
+          if (mean(data$temperature[1:10], na.rm = TRUE) > 50) {
+            warning("temperature value is unreaslistically high (> 50 Celcius) and will not be used.", call. = FALSE)
+            use.temp = FALSE
           }
-          if (!exists("PreviousLastValue")) PreviousLastValue = c(0, 0, 1)
-          if (!exists("PreviousLastTime")) PreviousLastTime = NULL
-          P = g.imputeTimegaps(P, xyzCol = xyzCol, timeCol = timeCol, sf = sf, k = 0.25,
-                               PreviousLastValue = PreviousLastValue,
-                               PreviousLastTime = PreviousLastTime,
-                               epochsize = c(ws3, ws2))
-          QClog = rbind(QClog, P$QClog)
-          P = P$x 
-          PreviousLastValue = as.numeric(P[nrow(P), xyzCol])
-          if (is.null(timeCol)) PreviousLastTime = NULL else PreviousLastTime = as.POSIXct(P[nrow(P), timeCol])
         }
-        data = P
-      } else if (dformat == FORMAT$CWA) {
-        if (P$header$hardwareType == "AX6") {
-          # GGIR now ignores the AX6 gyroscope signals until added value has robustly been demonstrated.
-          # Note however that while AX6 is able to collect gyroscope data, it can also be configured
-          # to only collect accelerometer data, so only remove gyro data if it's present.
-          if (ncol(P$data) == 10) {
-            data = P$data[,-c(2:4)]
-            P$data = P$data[1:min(100,nrow(P$data)),-c(2:4)] # trim object, because rest of data is not needed anymore
-          } else {
-            data = P$data
-            P$data = P$data[1:min(100,nrow(P$data)),] # trim object, because rest of data is not needed anymore
-          }
-          gyro_available = FALSE
-          # If we ever want to use gyroscope data then
-          # comment out this if statement and set gyro_available = TRUE
+
+        # output matrix for 15 minutes summaries
+        if (!use.temp && !light.available) {
+          metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 4)
+          metricnames_long = c("timestamp","nonwearscore","clippingscore","EN")
+        } else if (use.temp && !light.available) {
+          metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 5)
+          metricnames_long = c("timestamp","nonwearscore","clippingscore","temperaturemean","EN")
+        } else if (!use.temp && light.available) {
+          metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 6)
+          metricnames_long = c("timestamp","nonwearscore","clippingscore","lightmean","lightpeak","EN")
+        } else if (use.temp && light.available) {
+          metalong = matrix(" ", ((nev/(sf*ws2)) + 100), 7)
+          metricnames_long = c("timestamp","nonwearscore","clippingscore","lightmean","lightpeak","temperaturemean","EN")
+        }
+      }
+
+      if (params_rawdata[["imputeTimegaps"]] && (dformat == FORMAT$CSV || dformat == FORMAT$GT3X)) {
+        P = g.imputeTimegaps(data, sf = sf, k = 0.25,
+                             PreviousLastValue = PreviousLastValue,
+                             PreviousLastTime = PreviousLastTime,
+                             epochsize = c(ws3, ws2))
+        data = P$x
+        PreviousLastValue = data[nrow(data), c("x", "y", "z")]
+        if ("time" %in% colnames(data)) {
+          PreviousLastTime = as.POSIXct(data$time[nrow(data)])
         } else {
-          data = P$data
-          P$data = P$data[1:min(100,nrow(P$data)),] # trim object, because rest of data is not needed anymore
+          PreviousLastTime = NULL
         }
         QClog = rbind(QClog, P$QClog)
-      } else if (dformat == FORMAT$AD_HOC_CSV) {
-        data = P$data
-      } else if (mon == MONITOR$MOVISENS) {
-        data = P
-      } else if (dformat == FORMAT$GT3X) {
-        if (params_rawdata[["imputeTimegaps"]] == TRUE) {
-          if (!exists("PreviousLastValue")) PreviousLastValue = c(0, 0, 1)
-          if (!exists("PreviousLastTime")) PreviousLastTime = NULL
-          P = g.imputeTimegaps(P, xyzCol = c("X", "Y", "Z"), timeCol = "time", sf = sf, k = 0.25,
-                               PreviousLastValue = PreviousLastValue,
-                               PreviousLastTime = PreviousLastTime,
-                               epochsize = c(ws3, ws2))
-          QClog = rbind(QClog, P$QClog)
-          P = P$x 
-          PreviousLastValue = as.numeric(P[nrow(P), c("X", "Y", "Z")])
-          PreviousLastTime = as.POSIXct(P[nrow(P), "time"])
-        }
-        data = P[,2:ncol(P)]
+        rm(P)
       }
+
+      gc()
+
       data = as.matrix(data, rownames.force = FALSE)
-      #add left over data from last time
+      #add leftover data from last time
       if (nrow(S) > 0) {
-        if (params_rawdata[["imputeTimegaps"]] == TRUE) {
+        if (params_rawdata[["imputeTimegaps"]]) {
           if ("remaining_epochs" %in% colnames(data)) {
             if (ncol(S) == (ncol(data) - 1)) {
               # this block has time gaps while the previous block did not
               S = cbind(S, 1)
               colnames(S)[4] = "remaining_epochs"
             }
-          } else if ("remaining_epochs" %in% colnames(S) == TRUE) {
+          } else if ("remaining_epochs" %in% colnames(S)) {
             if ((ncol(S) - 1) == ncol(data)) {
               # this block does not have time gaps while the previous blog did
               data = cbind(data, 1)
@@ -347,40 +255,27 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
             }
           }
         }
-        data = suppressWarnings(rbind(S,data)) # suppress warnings about string as factor
+        data = rbind(S,data)
       }
-      SWMT = get_starttime_weekday_meantemp_truncdata(temp.available, mon, dformat,
-                                                      data,
-                                                      P, header, desiredtz = params_general[["desiredtz"]],
-                                                      sf, i, datafile,  ws2,
-                                                      starttime, wday, wdayname, configtz = params_general[["configtz"]])
-      starttime = SWMT$starttime
-      meantemp = SWMT$meantemp
-      use.temp = SWMT$use.temp
-      wday = SWMT$wday; wdayname = SWMT$wdayname
-      params_general[["desiredtz"]] = SWMT$desiredtz; data = SWMT$data
-      
-      if (mon == MONITOR$ACTIGRAPH || mon == MONITOR$VERISENSE ||
-          (mon == MONITOR$AXIVITY && dformat == FORMAT$CSV) ||
-          (mon == MONITOR$AD_HOC && use.temp == FALSE)) {
-        metricnames_long = c("timestamp","nonwearscore","clippingscore","en")
-      } else if (mon == MONITOR$GENEACTIV || (mon == MONITOR$AXIVITY && dformat == FORMAT$CWA)) {
-        metricnames_long = c("timestamp","nonwearscore","clippingscore","lightmean","lightpeak","temperaturemean","EN")
-      } else if (mon == MONITOR$MOVISENS || (mon == MONITOR$AD_HOC & use.temp == TRUE)) { 
-        # at the moment read.myacc.csv does not facilitate extracting light data, so only temperature is used
-        metricnames_long = c("timestamp","nonwearscore","clippingscore","temperaturemean","EN")
+      if (i == 1) {
+        SWMT = get_starttime_weekday_truncdata(mon, dformat,
+                                               data, header, desiredtz = params_general[["desiredtz"]],
+                                               sf, datafile,  ws2,
+                                               configtz = params_general[["configtz"]])
+        starttime = SWMT$starttime
+        wday = SWMT$wday; wdayname = SWMT$wdayname
+        data = SWMT$data
+        
+        rm(SWMT)
       }
-      rm(SWMT)
-      if (exists("P")) rm(P); gc()
-      if (i != 0 & exists("P")) rm(P); gc()
+
       LD = nrow(data)
-      if (LD < (ws*sf) & i == 1) {
+      if (LD < (ws*sf) && i == 1) {
         warning('\nWarning data too short for doing non-wear detection 3\n')
-        switchoffLD = 1
+        isLastBlock = TRUE
         LD = 0 #ignore rest of the data and store what has been loaded so far.
       }
       
-      
       #store data that could not be used for this block, but will be added to next block
       if (LD >= (ws*sf)) {
         
@@ -392,7 +287,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           }
         }
         if ((LD - use) > 1) {
-          S = data[(use + 1):LD,] #store left over
+          S = data[(use + 1):LD,] #store leftover data
           if (ncol(S) == 1) {
             S = t(S)
           }
@@ -411,101 +306,24 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         dur = nrow(data)	#duration of experiment in data points
         durexp = nrow(data) / (sf*ws)	#duration of experiment in hrs
         #--------------------------------------------
-        if (mon == MONITOR$GENEACTIV || (mon == MONITOR$AXIVITY && dformat == FORMAT$CWA) || mon == MONITOR$MOVISENS ||
-            (mon == MONITOR$AD_HOC && length(params_rawdata[["rmc.col.temp"]]) > 0)) {
-          if (mon == MONITOR$GENEACTIV) {
-            temperaturecolumn = 6; lightcolumn = 5
-          } else if (mon == MONITOR$AXIVITY) {
-            temperaturecolumn = 5; lightcolumn = 7
-            if (gyro_available == TRUE) {
-              temperaturecolumn = temperaturecolumn + 3
-              lightcolumn = lightcolumn + 3
-            }
-          } else if (mon == MONITOR$MOVISENS) {
-            temperaturecolumn = 4
-          } else if (mon == MONITOR$AD_HOC) {
-            temperaturecolumn = which(colnames(data) == "temperature")
-          }
-          if (mon != MONITOR$AD_HOC && mon != MONITOR$MOVISENS) {
-            light = as.numeric(data[, lightcolumn])
-          }
-          if (mon == MONITOR$AD_HOC && length(params_rawdata[["rmc.col.wear"]]) > 0) {
-            wearcol = as.character(data[, which(colnames(data) == "wear")])
-            suppressWarnings(storage.mode(wearcol) <- "logical")
-          }
-          temperature = as.numeric(data[, temperaturecolumn])
+        temperature = light = c()
+        if (light.available) {
+          light = data[, "light"]
         }
-        # Initialization of variables
-        data_scaled = FALSE
-        if (mon == MONITOR$ACTIGRAPH && dformat == FORMAT$GT3X) {
-          data = data[, 1:3]
-          data[, 1:3] = scale(data[, 1:3], center = -offset, scale = 1/scale) #rescale data
-          data_scaled = TRUE
-        } else if (mon == MONITOR$AXIVITY && (dformat == FORMAT$CWA || dformat == FORMAT$CSV)) {
-          extraction_succeeded = FALSE
-          if (gyro_available == TRUE) {
-            data[,5:7] = scale(data[,5:7],center = -offset, scale = 1/scale) #rescale data
-            extraction_succeeded = TRUE
-            data = data[, 2:7]
-          }
-          if (extraction_succeeded == FALSE) {
-            data[, 2:4] = scale(data[, 2:4],center = -offset, scale = 1/scale) #rescale data
-            data = data[,2:4]
-          }
-          data_scaled = TRUE
-        } else if (mon == MONITOR$GENEACTIV && dformat == FORMAT$BIN) {
-          yy = as.matrix(cbind(as.numeric(data[,temperaturecolumn]),
-                               as.numeric(data[,temperaturecolumn]),
-                               as.numeric(data[,temperaturecolumn])))
-          data = data[,2:4]
-          data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
-            scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
-          rm(yy); gc()
-          data_scaled = TRUE
-        } else if (mon == MONITOR$MOVISENS) {
-          yy = as.matrix(cbind(as.numeric(data[,4]),as.numeric(data[,4]),as.numeric(data[,4])))
-          data = data[,1:3]
-          data[,1:3] = scale(as.matrix(data[,1:3]),center = -offset, scale = 1/scale) +
-            scale(yy, center = rep(meantemp,3), scale = 1/tempoffset)  #rescale data
-          rm(yy); gc()
-          data_scaled = TRUE
-        } else if ((dformat == FORMAT$CSV || dformat == FORMAT$AD_HOC_CSV) && (mon != MONITOR$AXIVITY)) {
-          # Any brand that is not Axivity with csv or Movisense format data
-          if (mon == MONITOR$GENEACTIV || (mon == MONITOR$AD_HOC && use.temp == TRUE)) {
-            tempcolumnvalues = as.numeric(as.character(data[,temperaturecolumn]))
-            yy = as.matrix(cbind(tempcolumnvalues, tempcolumnvalues, tempcolumnvalues))
-            meantemp = mean(as.numeric(data[,temperaturecolumn]))
-            if (length(meantempcal) == 0) meantempcal = meantemp
-          }
-          if (ncol(data) == 3) data = data[,1:3]
-          if (ncol(data) >= 4) {
-            data = data[,2:4]
-            if (is(data[,1], "character")) {
-              data = apply(data, 2,as.numeric)
-            }
-          }
-          suppressWarnings(storage.mode(data) <- "numeric")
-          if ((mon == MONITOR$ACTIGRAPH || mon == MONITOR$AD_HOC || mon == MONITOR$VERISENSE) && use.temp == FALSE) {
-            data = scale(data,center = -offset, scale = 1/scale)  #rescale data
-          } else if ((mon == MONITOR$GENEACTIV || mon == MONITOR$AD_HOC) && use.temp == TRUE) {
-            # meantemp replaced by meantempcal # 19-12-2013
-            data = scale(data,center = -offset, scale = 1/scale) +
-              scale(yy, center = rep(meantempcal,3), scale = 1/tempoffset)  #rescale data
-            rm(yy); gc()
-          }
-          data_scaled = TRUE
+        if (use.temp) {
+          temperature = data[, "temperature"]
         }
-        if (data_scaled == FALSE) {
-          warning(paste0("\nAutocalibration was not applied, this should",
-                         "not happen please contact GGIR maintainers"))
+
+        # rescale data
+        data[, c("x", "y", "z")] = scale(data[, c("x", "y", "z")], center = -offset, scale = 1/scale)
+        if (use.temp && length(meantempcal) > 0) {
+          yy = cbind(temperature,
+                     temperature,
+                     temperature)
+          data[, c("x", "y", "z")] = data[, c("x", "y", "z")] + scale(yy, center = rep(meantempcal,3), scale = 1/tempoffset)
         }
-        suppressWarnings(storage.mode(data) <- "numeric")
-        ## resample experiment to see whehter processing time can be much improved if data is resampled
-        sfold = sforiginal # keep sf, because light, temperature are not resampled at the moment
-        # STORE THE RAW DATA
-        # data[,1], data[,2], data[,3], starttime, (temperature, light)
-        
-        EN = sqrt(data[,1]^2 + data[,2]^2 + data[,3]^2) # Do not delete Used for long epoch calculation
+
+        EN = sqrt(data[, "x"]^2 + data[, "y"]^2 + data[, "z"]^2) # Do not delete Used for long epoch calculation
         accmetrics = g.applymetrics(data = data,
                                     sf = sf, ws3 = ws3,
                                     metrics2do = metrics2do,
@@ -551,7 +369,6 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
           metashort = rbind(metashort,extension)
           extension2 = matrix(" ", ((3600/ws2) * 24)  + (totalgap * (ws2/ws3)), ncol(metalong)) #add another day to metashort once you reach the end of it
           metalong = rbind(metalong, extension2)
-          if (verbose == TRUE) cat("\nvariable metashort extended\n")
         }
         col_msi = 2
         # Add metric time series to metashort object
@@ -593,7 +410,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         blocksize = BlocksizeNew$blocksize
         ##==================================================
         # MODULE 2 - non-wear time & clipping
-        NWCW = detect_nonwear_clipping(data = data, windowsizes = c(ws3, ws2, ws), sf = sfold,
+        NWCW = detect_nonwear_clipping(data = data, windowsizes = c(ws3, ws2, ws), sf = sf,
                                        clipthres = clipthres, sdcriter = sdcriter, racriter = racriter,
                                        nonwear_approach = params_cleaning[["nonwear_approach"]],
                                        params_rawdata = params_rawdata)
@@ -601,49 +418,49 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
         # metalong
         col_mli = 2
         metalong[count2:((count2 - 1) + length(NWav)),col_mli] = NWav; col_mli = col_mli + 1
-        metalong[(count2):((count2 - 1) + length(NWav)),col_mli] = CWav; col_mli = col_mli + 1
-        if (mon == MONITOR$GENEACTIV || (mon == MONITOR$AXIVITY && dformat == FORMAT$CWA) || 
-            mon == MONITOR$MOVISENS || (mon == MONITOR$AD_HOC && length(params_rawdata[["rmc.col.temp"]]) != 0)) { # going from sample to ws2
-          if (mon == MONITOR$GENEACTIV || mon == MONITOR$AXIVITY) {
-            #light (running mean)
-            lightc = cumsum(c(0,light))
-            select = seq(1, length(lightc), by = (ws2 * sfold))
-            lightmean = diff(lightc[round(select)]) / abs(diff(round(select)))
-            rm(lightc); gc()
-            #light (running max)
-            lightmax = matrix(0, length(lightmean), 1)
-            for (li in 1:(length(light)/(ws2*sfold))) {
-              tempm = max(light[((li - 1) * (ws2 * sfold)):(li * (ws2 * sfold))])
-              if (length(tempm) > 0) {
-                lightmax[li] = tempm[1]
-              } else {
-                lightmax[li] = max(light[((li - 1) * (ws2 * sfold)):(li * (ws2 * sfold))])
-              }
+        metalong[count2:((count2 - 1) + length(NWav)),col_mli] = CWav; col_mli = col_mli + 1
+
+        if(light.available) {
+          #light (running mean)
+          lightc = cumsum(c(0,light))
+          select = seq(1, length(lightc), by = (ws2 * sf))
+          lightmean = diff(lightc[round(select)]) / abs(diff(round(select)))
+          rm(lightc)
+          #light (running max)
+          lightmax = matrix(0, length(lightmean), 1)
+          for (li in 1:(length(light)/(ws2*sf))) {
+            tempm = max(light[((li - 1) * (ws2 * sf)):(li * (ws2 * sf))])
+            if (length(tempm) > 0) {
+              lightmax[li] = tempm[1]
+            } else {
+              lightmax[li] = max(light[((li - 1) * (ws2 * sf)):(li * (ws2 * sf))])
             }
           }
-          #temperature (running mean)
-          temperaturec = cumsum(c(0, temperature))
-          select = seq(1, length(temperaturec), by = (ws2 * sfold))
-          temperatureb = diff(temperaturec[round(select)]) / abs(diff(round(select)))
-          rm(temperaturec); gc()
-        }
-        #EN going from sample to ws2
-        ENc = cumsum(c(0, EN))
-        select = seq(1, length(ENc), by = (ws2 * sf)) #<= EN is derived from data, so it needs the new sf
-        ENb = diff(ENc[round(select)]) / abs(diff(round(select)))
-        rm(ENc, EN); gc()
-        if (mon == MONITOR$GENEACTIV || (mon == MONITOR$AXIVITY && dformat == FORMAT$CWA)) {
+
           metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(lightmean, digits = n_decimal_places)
           col_mli = col_mli + 1
           metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(lightmax, digits = n_decimal_places)
           col_mli = col_mli + 1
-          metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(temperatureb, digits = n_decimal_places)
-          col_mli = col_mli + 1
-        } else if (mon == MONITOR$MOVISENS || (mon == MONITOR$AD_HOC && length(params_rawdata[["rmc.col.temp"]]) != 0)) {
+        }
+
+        if(use.temp) {
+          #temperature (running mean)
+          temperaturec = cumsum(c(0, temperature))
+          select = seq(1, length(temperaturec), by = (ws2 * sf))
+          temperatureb = diff(temperaturec[round(select)]) / abs(diff(round(select)))
+          rm(temperaturec)
+
           metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(temperatureb, digits = n_decimal_places)
           col_mli = col_mli + 1
         }
+
+        #EN going from sample to ws2
+        ENc = cumsum(c(0, EN))
+        select = seq(1, length(ENc), by = (ws2 * sf)) #<= EN is derived from data, so it needs the new sf
+        ENb = diff(ENc[round(select)]) / abs(diff(round(select)))
+        rm(ENc, EN)
         metalong[(count2):((count2 - 1) + length(NWav)), col_mli] = round(ENb, digits = n_decimal_places)
+
         if (exists("remaining_epochs")) {
           # Impute long gaps at epoch levels, because imputing them at raw level would
           # be too memory hungry
@@ -686,13 +503,13 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
             # metalong
             metalong = impute_at_epoch_level(gapsize = floor(remaining_epochs[gaps_to_fill] * (ws3/ws2)) + 1, # plus 1 needed to count for current epoch
                                              timeseries = metalong,
-                                             gap_index = floor(gaps_to_fill / (ws2 * sfold)) + count2, # Using floor so that the gap is filled in the epoch in which it is occurring
+                                             gap_index = floor(gaps_to_fill / (ws2 * sf)) + count2, # Using floor so that the gap is filled in the epoch in which it is occurring
                                              metnames = metricnames_long)
             # metashort
             # added epoch-level nonwear to metashort to get it imputed, then remove it
             metashort = impute_at_epoch_level(gapsize = remaining_epochs[gaps_to_fill], # gapsize in epochs
                                               timeseries = metashort,
-                                              gap_index = floor(gaps_to_fill / (ws3 * sfold)) + count, # Using floor so that the gap is filled in the epoch in which it is occurring
+                                              gap_index = floor(gaps_to_fill / (ws3 * sf)) + count, # Using floor so that the gap is filled in the epoch in which it is occurring
                                               metnames = c("timestamp", metnames)) # epoch level index of gap
             nr_after = c(nrow(metalong), nrow(metashort))
             count2 = count2 + (nr_after[1] - nr_before[1])
@@ -711,7 +528,7 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
       LD = 0 #once LD < 1 the analysis stops, so this is a trick to stop it
       # stop reading because there is not enough data in this block
     }
-    if (switchoffLD == 1) LD = 0
+    if (isLastBlock) LD = 0
     if (ceiling(daylimit) != FALSE) {
       if (i == ceiling(daylimit)) { #to speed up testing only read first 'i' blocks of data
         LD = 0 #once LD < 1 the analysis stops, so this is a trick to stop it
@@ -721,38 +538,30 @@ g.getmeta = function(datafile, params_metrics = c(), params_rawdata = c(),
     i = i + 1 #go to next block
   }
   # deriving timestamps
-  if (filecorrupt == FALSE & filetooshort == FALSE & filedoesnotholdday == FALSE) {
+  if (!filecorrupt && !filetooshort && !filedoesnotholdday) {
     cut = count:nrow(metashort)
     if (length(cut) > 1) {
-      tmp = metashort[-cut,]
+      metashort = metashort[-cut,]
       # for a very small file, there could be just one row in metashort[-cut,], so it gets coerced to a vector.
       # But what we actually need is a 1-row matrix. So we need to transpose it. 
-      if(is.vector(tmp)) { 
-        metashort = as.matrix(t(tmp))
-      } else {
-        metashort = as.matrix(tmp)
+      if(is.vector(metashort)) { 
+        metashort = as.matrix(t(metashort))
       }
     }
     if (nrow(metashort) > 1) {
       starttime3 = round(as.numeric(starttime)) #numeric time but relative to the desiredtz
       time5 = seq(starttime3, (starttime3 + ((nrow(metashort) - 1) * ws3)), by = ws3)
-      if (length(params_general[["desiredtz"]]) == 0) {
-        warning("\ndesiredtz not specified, system timezone used as default")
-        params_general[["desiredtz"]] = ""
-      }
       time6 = as.POSIXlt(time5,origin = "1970-01-01", tz = params_general[["desiredtz"]])
       time6 = strftime(time6, format = "%Y-%m-%dT%H:%M:%S%z")
       metashort[,1] = as.character(time6)
     }
     cut2 = count2:nrow(metalong)
     if (length(cut2) > 1) {
-      tmp = metalong[-cut2,]
+      metalong = metalong[-cut2,]
       # for a very small file, there could be just one row in metalong[-cut2,], so it gets coerced to a vector.
       # But what we actually need is a 1-row matrix. So we need to transpose it. 
-      if(is.vector(tmp)) { 
-        metalong = as.matrix(t(tmp))
-      } else {
-        metalong = as.matrix(tmp)
+      if(is.vector(metalong)) { 
+        metalong = as.matrix(t(metalong))
       }
     }
     if (nrow(metalong) > 2) {
