@@ -112,7 +112,9 @@ load_params = function(topic = c("sleep", "metrics", "rawdata",
                          week_weekend_aggregate.part5 = FALSE, do.part3.pdf = TRUE,
                          outliers.only = FALSE, criterror = 3, do.visual = TRUE,
                          do.sibreport = FALSE, do.part2.pdf = TRUE,
-                         sep_reports = ",", sep_config = ",", visualreport_without_invalid = TRUE)
+                         sep_reports = ",", sep_config = ",", 
+                         dec_reports = ".", dec_config = ".", 
+                         visualreport_without_invalid = TRUE)
 
   }
   if ("general" %in% topic) {
